#[derive(Decode)]
{
// Attributes available to this derive:
#[secret]
}
Available on crate feature
derive only.Expand description
Derive an Decode implementation for a struct or enum.
#[derive(Decode)]
{
// Attributes available to this derive:
#[secret]
}
derive only.Derive an Decode implementation for a struct or enum.